@@ -10,12 +10,12 @@ function(topic, assign.global=TRUE)
     dcel <- listDcExamples()
     href <- paste(getOption("dcmle.href"), "/",
         dcel[,"href"], "/", dcel[,"topic"], ".R", sep="")
-    TOPIC <- dcel[,"topic"]
+    TOPIC <- as.character(dcel[,"topic"])
     if (missing(topic))
         return(TOPIC)
     e <- new.env()
-    eval(parse(href[TOPIC==topic]), e)
+    eval(parse(href[TOPIC==as.character(topic)]), e)
     if (assign.global)
         assign(topic, e[[topic]], envir=.GlobalEnv)
-    invisible(e[[topic]])
+    invisible(e[[as.character(topic)]])
 }
